You can read more about how to find older civil justice records in the research guide [Criminal courts: appeal cases](https://www.nationalarchives.gov.uk/help-with-your-research/research-guides/criminal-courts-appeal-cases/){target="\_blank"}.
